@@ -7,14 +7,7 @@ use File::Spec; # core
 use Module::Build;
 @App::Netdisco::Builder::ISA = qw(Module::Build);
 
-our $home;
-
-BEGIN {
-    $home = ($ENV{NETDISCO_HOME} || $ENV{HOME});
-    $ENV{POETRY_CACHE_DIR} ||= File::Spec->catdir($home, 'python', 'cache', 'pypoetry');
-}
-
-sub ACTION_poetry {
+sub ACTION_python {
     my $self = shift;
     require App::Netdisco::Util::Python;
     $self->do_system( App::Netdisco::Util::Python::py_install() );
@@ -23,7 +16,7 @@ sub ACTION_poetry {
 sub ACTION_install {
     my $self = shift;
     $self->SUPER::ACTION_install;
-    $self->ACTION_poetry;
+    $self->ACTION_python;
 }
 
 1;
