@@ -15,8 +15,8 @@ __PACKAGE__->result_source_instance->view_definition(<<ENDSQL
   FROM device_port
   LEFT OUTER JOIN device_port_properties dpp USING (ip, port)
   WHERE port !~* 'vlan'
+    AND (descr IS NULL OR descr !~* 'vlan')
     AND (type IS NULL OR type !~* '^(53|ieee8023adLag|propVirtual|l2vlan|l3ipvlan|135|136|137)\$')
-    AND (name IS NULL OR name !~* 'vlan')
     AND (is_master = 'false' OR slave_of IS NOT NULL)
   GROUP BY ip
   ORDER BY total DESC, ip ASC
